This step is optional if you have Python 3.7 or 3.8 installed (run `python --version`
in a terminal and check the version that is printed). If you don't have Python 3.7, we
recommend using Anaconda for setting up requirements because it is very easy (but any way
of installing Python 3.7 is fine). If you do not have Anaconda yet, follow their
[installation instructions](https://docs.anaconda.com/anaconda/install/).

After installing Anaconda, to set up a Python 3.7 environment (in case you don't have one
yet) execute:

```bash
conda create --yes -n newsmtsc python=3.7
conda activate newsmtsc
```
